ChunkStat

Struct ChunkStat 

pub struct ChunkStat<Chkp> {
    pub chunk_id: ChunkId,
    pub records_count: u64,
    pub global_start: u64,
    pub global_end: u64,
    pub size: u64,
    pub log_state: Chkp,
}
Statistics about a single chunk in the WAL.

Fields

chunk_id: ChunkId

Unique identifier for this chunk.

records_count: u64

Number of records stored in this chunk.

global_start: u64

Global offset of the first record in this chunk.

global_end: u64

Global offset after the last record in this chunk.

size: u64

Size of the chunk in bytes.

log_state: Chkp

Checkpoint stored for this chunk.