Config

Struct Config 

pub struct Config {
    pub dir: String,
    pub read_buffer_size: Option<usize>,
    pub chunk_max_records: Option<usize>,
    pub chunk_max_size: Option<usize>,
    pub truncate_incomplete_record: Option<bool>,
    pub flush_batch_wait: Option<Duration>,
    pub flush_batch_max_items: Option<usize>,
}
Configuration for chunked WAL.

This struct holds directory, chunk, recovery, and flush batching settings.

Optional parameters are Option<T> in this struct, and default values is evaluated when a getter method is called.

Fields

dir: String

Base directory for storing WAL files.

read_buffer_size: Option<usize>

Size of the read buffer in bytes.

chunk_max_records: Option<usize>

Maximum number of records in a chunk.

chunk_max_size: Option<usize>

Maximum size of a chunk in bytes.

truncate_incomplete_record: Option<bool>

Whether to truncate the last half sync-ed record.

If truncate, the chunk is considered successfully opened. Otherwise, an io::Error will be returned.

flush_batch_wait: Option<Duration>

Maximum time the flush worker waits for more write requests before starting a sync batch.

Defaults to 1 millisecond.

flush_batch_max_items: Option<usize>

Maximum number of write requests to include in one flush batch.

Defaults to 2048. Values smaller than 1 are treated as 1.

Implementations

Source

impl Config

pub fn new(dir: impl ToString) -> Self

Creates a new Config with the specified directory and defaults.

pub fn new_full( dir: impl ToString, read_buffer_size: Option<usize>, chunk_max_records: Option<usize>, chunk_max_size: Option<usize>, ) -> Self

Creates a new Config with all configurable parameters

pub fn read_buffer_size(&self) -> usize

Returns the size of read buffer in bytes (defaults to 64MB)

pub fn chunk_max_records(&self) -> usize

Returns the maximum number of records per chunk (defaults to 1M records)

pub fn chunk_max_size(&self) -> usize

Returns the maximum size of a chunk in bytes (defaults to 1GB)

pub fn truncate_incomplete_record(&self) -> bool

Returns whether to truncate incomplete records (defaults to true)

pub fn flush_batch_wait(&self) -> Duration

Returns the bounded wait before syncing a flush batch.

pub fn flush_batch_max_items(&self) -> usize

Returns the maximum number of write requests in one flush batch.

pub fn chunk_path(&self, chunk_id: ChunkId) -> String

Returns the full path for a given chunk ID

pub fn chunk_file_name(chunk_id: ChunkId) -> String

Generates the file name for a given chunk ID

The file name format is “r-{padded_chunk_id}.wal”

pub fn parse_chunk_file_name( file_name: &str, ) -> Result<u64, InvalidChunkFileName>

Parses a chunk file name and returns the chunk ID

Arguments
  • file_name - Name of the chunk file (format: “r-{padded_chunk_id}.wal”)
Returns
  • Ok(u64) - The chunk ID if parsing succeeds
  • Err(InvalidChunkFileName) - If the file name format is invalid